#R script file for the generation of metabolic heat maps from mass spectrometry data

#load data matrix into R
msdata <- read.table("massR.dat")

#extract mz-values as list
mzall<-msdata[,2]

#binning of mz-data with fixed intervals
mzbin1000 <- cut(mzall,breaks=seq(50, 2000, by = 1))

#convert resulting binning factor to vector
mzbin1000vector<-as.vector(mzbin1000)

#add binning information to data frame
msdata$bin<-mzbin1000vector

#remove data outside binning range
msdata <- msdata[!is.na(msdata[,4]),]
mzall<-msdata[,2]

#Generate non-redundant list of ms-files
msfiles<-unique(msdata[,1])
msfilesvector<-as.vector(msfiles)

#Non-redundant list of bins
msbins<-unique(msdata[,4])

#generate empty output matrix
outputmatrix <- matrix(0, nrow = length(msfilesvector), ncol = length(msbins))
rownames(outputmatrix)<-msfilesvector
colnames(outputmatrix)<-msbins

#fill matrix with data 
i=j=k=l=m=1
for (i in 1:length(mzall)) {for (l in 1:length(msfilesvector)) {if (msdata[i,1] == msfilesvector[l]) {j=l}}; for (m in 1:length(msbins)) {if (msdata[i,4] == msbins[m]) {k=m}}; outputmatrix[j,k]<-msdata[i,3]}

#spectra normalization
install.packages("vegetarian")
library(vegetarian)
normoutputmatrix<-normalize.rows(outputmatrix)
#optional:normormalization by median
#medianvalues<-as.vector(apply(outputmatrix,1,median))
#normoutputmatrix<-outputmatrix/medianvalues

rownames(normoutputmatrix)<-msfilesvector
colnames(normoutputmatrix)<-msbins

#find maximal value for each column (mz-bin)
columnmax<-apply(normoutputmatrix, 2, max)

#sort and select the 100 most intense values
colmax<-sort(columnmax,decreasing=TRUE)
colmaxselection<-as.matrix(colmax[1:100])
colmaxselection=as.vector(rownames(colmaxselection))

#limiting matrix to selection
normoutputmatrix<-normoutputmatrix[,colmaxselection]

#Generation of heat maps
install.packages("pheatmap")
library(pheatmap)

#transformation of matrices
tnormoutputmatrix<-t(normoutputmatrix)

#Legend for metabolic heat map
ann_text = data.frame(Plant = c("CV-702 Control","CV-702 Control","CV-702 Control","CV-702 Low N","CV-702 Low N","CV-702 Low N","E-132 Control","E-132 Control","E-132 Control","E-132 Drought","E-132 Drought","E-132 Drought"))
rownames(ann_text) = msfiles

Plant = c("lightblue", "darkblue", "orange","red")
names(Plant) = c("CV-702 Control","CV-702 Low N","E-132 Control","E-132 Drought")

ann_colors = list(Plant = Plant)

pheatmap(tnormoutputmatrix,scale="row",cluster_cols = TRUE, cluster_rows = TRUE, clustering_distance_rows="euclidean", clustering_distance_cols="euclidean", clustering_methode="complete",cellwidth = NA, cellheight = NA, fontsize=5, annotation = ann_text, annotation_colors = ann_colors,show_colnames=FALSE,filename="metabolic-heatmap-100.pdf")
